@@ -8,11 +8,6 @@
     :copyright: 2010 by Daniel Neuhäuser
     :license: BSD, see LICENSE.rst for details
 """
-try:
-    from itertools import izip, ifilter
-except ImportError:
-    izip = zip
-    ifilter = filter
 try:
     from functools import reduce
 except ImportError:
